==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/GUITestBase/src/tests/common_scenarios/shared_database/GTTestsSharedDatabase.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _GTTESTS_SHARED_DATABASE_H_
#define _GTTESTS_SHARED_DATABASE_H_

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_shared_database {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_shared_database"

GUI_TEST_CLASS_DECLARATION(cm_test_0001)
GUI_TEST_CLASS_DECLARATION(cm_test_0002)
GUI_TEST_CLASS_DECLARATION(cm_test_0003)
GUI_TEST_CLASS_DECLARATION(cm_test_0004)
GUI_TEST_CLASS_DECLARATION(cm_test_0005)
GUI_TEST_CLASS_DECLARATION(cm_test_0006)
GUI_TEST_CLASS_DECLARATION(cm_test_0007)
GUI_TEST_CLASS_DECLARATION(cm_test_0008)
GUI_TEST_CLASS_DECLARATION(cm_test_0009)
GUI_TEST_CLASS_DECLARATION(cm_test_0013)
GUI_TEST_CLASS_DECLARATION(cm_test_0014)

GUI_TEST_CLASS_DECLARATION(proj_test_0001)
GUI_TEST_CLASS_DECLARATION(proj_test_0002)
GUI_TEST_CLASS_DECLARATION(proj_test_0003)
GUI_TEST_CLASS_DECLARATION(proj_test_0004)
GUI_TEST_CLASS_DECLARATION(proj_test_0005)
GUI_TEST_CLASS_DECLARATION(proj_test_0006)
GUI_TEST_CLASS_DECLARATION(proj_test_0007)
GUI_TEST_CLASS_DECLARATION(proj_test_0008)
GUI_TEST_CLASS_DECLARATION(proj_test_0009)

GUI_TEST_CLASS_DECLARATION(import_test_0001)
GUI_TEST_CLASS_DECLARATION(import_test_0002)
GUI_TEST_CLASS_DECLARATION(import_test_0003)
GUI_TEST_CLASS_DECLARATION(import_test_0004)
GUI_TEST_CLASS_DECLARATION(import_test_0005)
GUI_TEST_CLASS_DECLARATION(import_test_0006)
GUI_TEST_CLASS_DECLARATION(import_test_0007)
GUI_TEST_CLASS_DECLARATION(import_test_0008)
GUI_TEST_CLASS_DECLARATION(import_test_0009)
GUI_TEST_CLASS_DECLARATION(import_test_0010)
GUI_TEST_CLASS_DECLARATION(import_test_0011)
GUI_TEST_CLASS_DECLARATION(import_test_0012)
GUI_TEST_CLASS_DECLARATION(import_test_0013)
GUI_TEST_CLASS_DECLARATION(import_test_0014)
GUI_TEST_CLASS_DECLARATION(import_test_0015)
GUI_TEST_CLASS_DECLARATION(import_test_0016)
GUI_TEST_CLASS_DECLARATION(import_test_0017)
GUI_TEST_CLASS_DECLARATION(import_test_0018)
GUI_TEST_CLASS_DECLARATION(import_test_0019)
GUI_TEST_CLASS_DECLARATION(import_test_0020)

GUI_TEST_CLASS_DECLARATION(view_test_0001)
GUI_TEST_CLASS_DECLARATION(view_test_0002)
GUI_TEST_CLASS_DECLARATION(view_test_0003)
GUI_TEST_CLASS_DECLARATION(view_test_0004)
GUI_TEST_CLASS_DECLARATION(view_test_0005)
GUI_TEST_CLASS_DECLARATION(view_test_0006)

GUI_TEST_CLASS_DECLARATION(del_test_0001)
GUI_TEST_CLASS_DECLARATION(del_test_0002)
GUI_TEST_CLASS_DECLARATION(del_test_0003)

GUI_TEST_CLASS_DECLARATION(export_test_0001)
GUI_TEST_CLASS_DECLARATION(export_test_0002)
GUI_TEST_CLASS_DECLARATION(export_test_0003)
GUI_TEST_CLASS_DECLARATION(export_test_0004)
GUI_TEST_CLASS_DECLARATION(export_test_0005)
GUI_TEST_CLASS_DECLARATION(export_test_0006)
GUI_TEST_CLASS_DECLARATION(export_test_0007)
GUI_TEST_CLASS_DECLARATION(export_test_0008)
GUI_TEST_CLASS_DECLARATION(export_test_0009)

}

} // U2

#endif // _GTTESTS_SHARED_DATABASE_H_

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/shared_database/GTTestsSharedDatabase.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _GTTESTS_SHARED_DATABASE_H_
#define _GTTESTS_SHARED_DATABASE_H_

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_shared_database {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_shared_database"

GUI_TEST_CLASS_DECLARATION(cm_test_0001)
GUI_TEST_CLASS_DECLARATION(cm_test_0002)
GUI_TEST_CLASS_DECLARATION(cm_test_0003)
GUI_TEST_CLASS_DECLARATION(cm_test_0004)
GUI_TEST_CLASS_DECLARATION(cm_test_0005)
GUI_TEST_CLASS_DECLARATION(cm_test_0006)
GUI_TEST_CLASS_DECLARATION(cm_test_0007)
GUI_TEST_CLASS_DECLARATION(cm_test_0008)
GUI_TEST_CLASS_DECLARATION(cm_test_0009)
GUI_TEST_CLASS_DECLARATION(cm_test_0013)
GUI_TEST_CLASS_DECLARATION(cm_test_0014)

GUI_TEST_CLASS_DECLARATION(proj_test_0001)
GUI_TEST_CLASS_DECLARATION(proj_test_0002)
GUI_TEST_CLASS_DECLARATION(proj_test_0003)
GUI_TEST_CLASS_DECLARATION(proj_test_0004)
GUI_TEST_CLASS_DECLARATION(proj_test_0005)
GUI_TEST_CLASS_DECLARATION(proj_test_0006)
GUI_TEST_CLASS_DECLARATION(proj_test_0007)
GUI_TEST_CLASS_DECLARATION(proj_test_0008)
GUI_TEST_CLASS_DECLARATION(proj_test_0009)

GUI_TEST_CLASS_DECLARATION(import_test_0001)
GUI_TEST_CLASS_DECLARATION(import_test_0002)
GUI_TEST_CLASS_DECLARATION(import_test_0003)
GUI_TEST_CLASS_DECLARATION(import_test_0004)
GUI_TEST_CLASS_DECLARATION(import_test_0005)
GUI_TEST_CLASS_DECLARATION(import_test_0006)
GUI_TEST_CLASS_DECLARATION(import_test_0007)
GUI_TEST_CLASS_DECLARATION(import_test_0008)
GUI_TEST_CLASS_DECLARATION(import_test_0009)
GUI_TEST_CLASS_DECLARATION(import_test_0010)
GUI_TEST_CLASS_DECLARATION(import_test_0011)
GUI_TEST_CLASS_DECLARATION(import_test_0012)
GUI_TEST_CLASS_DECLARATION(import_test_0013)
GUI_TEST_CLASS_DECLARATION(import_test_0014)
GUI_TEST_CLASS_DECLARATION(import_test_0015)
GUI_TEST_CLASS_DECLARATION(import_test_0016)
GUI_TEST_CLASS_DECLARATION(import_test_0017)
GUI_TEST_CLASS_DECLARATION(import_test_0018)
GUI_TEST_CLASS_DECLARATION(import_test_0019)
GUI_TEST_CLASS_DECLARATION(import_test_0020)

GUI_TEST_CLASS_DECLARATION(view_test_0001)
GUI_TEST_CLASS_DECLARATION(view_test_0002)
GUI_TEST_CLASS_DECLARATION(view_test_0003)
GUI_TEST_CLASS_DECLARATION(view_test_0004)
GUI_TEST_CLASS_DECLARATION(view_test_0005)
GUI_TEST_CLASS_DECLARATION(view_test_0006)

GUI_TEST_CLASS_DECLARATION(del_test_0001)
GUI_TEST_CLASS_DECLARATION(del_test_0002)
GUI_TEST_CLASS_DECLARATION(del_test_0003)

GUI_TEST_CLASS_DECLARATION(export_test_0001)
GUI_TEST_CLASS_DECLARATION(export_test_0002)
GUI_TEST_CLASS_DECLARATION(export_test_0003)
GUI_TEST_CLASS_DECLARATION(export_test_0004)
GUI_TEST_CLASS_DECLARATION(export_test_0005)
GUI_TEST_CLASS_DECLARATION(export_test_0006)
GUI_TEST_CLASS_DECLARATION(export_test_0007)
GUI_TEST_CLASS_DECLARATION(export_test_0008)
GUI_TEST_CLASS_DECLARATION(export_test_0009)

}  // namespace GUITest_common_scenarios_shared_database

}  // namespace U2

#endif  // _GTTESTS_SHARED_DATABASE_H_
